The Error returned by sscanf.
Variants
MatchFailed
The Regex generated from the format string did not match the input
ParsingFailed(Box<dyn Error>)
One of the FromStr or FromScanf conversions failed
This variant usually indicates that a RegexRepresentation
of a type allows too many values to be accepted. This cannot always be avoided without
creating a ridiculously complex regex, and so this error is returned instead.
In those cases, it is fine to treat this as an extension of MatchFailed.
The exact content of this error is only relevant when debugging custom implementations of
FromStr or FromScanf.